@@ -1,4 +1,4 @@
-# (c) Copyright [2018-2020] Micro Focus or one of its affiliates.
+# (c) Copyright [2018-2022] Micro Focus or one of its affiliates.
 # Licensed under the Apache License, Version 2.0 (the "License");
 # You may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -36,14 +36,14 @@
 # \  / _  __|_. _ _ |_)
 #  \/ (/_|  | |(_(_|| \/
 #                     /
-# VerticaPy is a Python library with scikit-like functionality to use to conduct
+# VerticaPy is a Python library with scikit-like functionality for conducting
 # data science projects on data stored in Vertica, taking advantage Vertica’s
 # speed and built-in analytics and machine learning features. It supports the
 # entire data science life cycle, uses a ‘pipeline’ mechanism to sequentialize
 # data transformation operations, and offers beautiful graphical options.
 #
-# VerticaPy aims to solve all of these problems. The idea is simple: instead
-# of moving data around for processing, VerticaPy brings the logic to the data.
+# VerticaPy aims to do all of the above. The idea is simple: instead of moving
+# data around for processing, VerticaPy brings the logic to the data.
 #
 #
 # Modules
@@ -52,31 +52,31 @@
 import os
 
 # VerticaPy Modules
-import vertica_python
+import vertica_python, verticapy
+from verticapy import vDataFrame
+from verticapy.connect import current_cursor
 from verticapy.utilities import *
 from verticapy.toolbox import *
-from verticapy import vDataFrame
 from verticapy.errors import *
 from verticapy.learn.vmodel import *
+from verticapy.learn.tools import *
 
 # ---#
-class BisectingKMeans(Clustering):
+class BisectingKMeans(Clustering, Tree):
     """
 ---------------------------------------------------------------------------
-Creates a Bisecting KMeans object by using the Vertica Highly Distributed and 
-Scalable Bisecting KMeans on the data. KMeans clustering is a method of vector 
-quantization, originally from signal processing, that aims to partition n 
-observations into k clusters in which each observation belongs to the cluster 
-with the nearest mean (cluster centers or cluster centroid), serving as a 
-prototype of the cluster. This results in a partitioning of the data space into 
-Voronoi cells. Bisecting KMeans combines KMeans and Hierarchical clustering.
+Creates a BisectingKMeans object using the Vertica bisecting k-means 
+algorithm on the data. k-means clustering is a method of vector quantization, 
+originally from signal processing, that aims to partition n observations into 
+k clusters. Each observation belongs to the cluster with the nearest 
+mean (cluster centers or cluster centroid), which serves as a prototype of 
+the cluster. This results in a partitioning of the data space into Voronoi
+cells. Bisecting k-means combines k-means and hierarchical clustering.
 
 Parameters
 ----------
 name: str
     Name of the the model. The model will be stored in the DB.
-cursor: DBcursor, optional
-    Vertica DB cursor.
 n_cluster: int, optional
     Number of clusters
 bisection_iterations: int, optional
@@ -114,7 +114,6 @@ tol: float, optional
     def __init__(
         self,
         name: str,
-        cursor=None,
         n_cluster: int = 8,
         bisection_iterations: int = 1,
         split_method: str = "sum_squares",
@@ -124,7 +123,24 @@ tol: float, optional
         max_iter: int = 300,
         tol: float = 1e-4,
     ):
-        check_types([("name", name, [str],)])
+        # Saving information to the query profile table
+        save_to_query_profile(
+            name="BisectingKMeans",
+            path="learn.cluster",
+            json_dict={
+                "name": name,
+                "n_cluster": n_cluster,
+                "bisection_iterations": bisection_iterations,
+                "split_method": split_method,
+                "min_divisible_cluster_size": min_divisible_cluster_size,
+                "distance_method": distance_method,
+                "init": init,
+                "max_iter": max_iter,
+                "tol": tol,
+            },
+        )
+        # -#
+        check_types([("name", name, [str])])
         self.type, self.name = "BisectingKMeans", name
         self.set_params(
             {
@@ -138,34 +154,16 @@ tol: float, optional
                 "tol": tol,
             }
         )
-        cursor = check_cursor(cursor)[0]
-        self.cursor = cursor
-        version(cursor=cursor, condition=[9, 3, 1])
+        version(condition=[9, 3, 1])
 
     # ---#
     def get_tree(self):
         """
     ---------------------------------------------------------------------------
-    Returns a table with all the BK tree information.
+    Returns a table containing information about the BK-tree.
         """
         return self.cluster_centers_
 
-    # ---#
-    def plot_tree(self, pic_path: str = ""):
-        """
-    ---------------------------------------------------------------------------
-    Draws the input BKtree. The module anytree must be installed in the machine.
-
-    Parameters
-    ----------
-    pic_path: str, optional
-        Absolute path to save the image of the tree.
-        """
-        check_types(
-            [("pic_path", pic_path, [str],),]
-        )
-        plot_BKtree(self.cluster_centers_.values, pic_path=pic_path)
-
 
 # ---#
 class DBSCAN(vModel):
@@ -173,28 +171,26 @@ class DBSCAN(vModel):
 ---------------------------------------------------------------------------
 [Beta Version]
 Creates a DBSCAN object by using the DBSCAN algorithm as defined by Martin 
-Ester, Hans-Peter Kriegel, Jörg Sander and Xiaowei Xu. This object is using 
-pure SQL to compute all the distances and neighbors. It is also using Python 
-to compute the cluster propagation (non scalable phase).
+Ester, Hans-Peter Kriegel, Jörg Sander, and Xiaowei Xu. This object uses 
+pure SQL to compute the distances and neighbors and uses Python to compute 
+the cluster propagation (non-scalable phase).
 
-\u26A0 Warning : This Algorithm is computationally expensive. It is using a CROSS 
-                 JOIN during the computation. The complexity is O(n * n), n 
-                 being the total number of elements.
-                 It will index all the elements of the table in order to be optimal 
+\u26A0 Warning : This algorithm uses a CROSS JOIN during computation and
+                 is therefore computationally expensive at O(n * n), where
+                 n is the total number of elements.
+                 This algorithm indexes elements of the table in order to be optimal 
                  (the CROSS JOIN will happen only with IDs which are integers). 
-                 As DBSCAN is using the p-distance, it is highly sensible to 
-                 un-normalized data. However, DBSCAN is really robust to outliers 
-                 and can find non-linear clusters. It is a very powerful algorithm 
-                 for outliers detection and clustering. A table will be created 
+                 Since DBSCAN is uses the p-distance, it is highly sensitive to 
+                 unnormalized data. However, DBSCAN is robust to outliers and can 
+                 find non-linear clusters. It is a very powerful algorithm for 
+                 outliers detection and clustering. A table will be created 
                  at the end of the learning phase.
 
 Parameters
 ----------
 name: str
-	Name of the the model. As it is not a built in model, this name will be used
-	to build the final table.
-cursor: DBcursor, optional
-	Vertica DB cursor.
+	Name of the the model. This is not a built-in model, so this name will be used
+    to build the final table.
 eps: float, optional
 	The radius of a neighborhood with respect to some point.
 min_samples: int, optional
@@ -203,14 +199,17 @@ p: int, optional
 	The p of the p-distance (distance metric used during the model computation).
 	"""
 
-    def __init__(
-        self, name: str, cursor=None, eps: float = 0.5, min_samples: int = 5, p: int = 2
-    ):
-        check_types([("name", name, [str],)])
+    def __init__(self, name: str, eps: float = 0.5, min_samples: int = 5, p: int = 2):
+        # Saving information to the query profile table
+        save_to_query_profile(
+            name="DBSCAN",
+            path="learn.cluster",
+            json_dict={"name": name, "eps": eps, "min_samples": min_samples, "p": p,},
+        )
+        # -#
+        check_types([("name", name, [str])])
         self.type, self.name = "DBSCAN", name
         self.set_params({"eps": eps, "min_samples": min_samples, "p": p})
-        cursor = check_cursor(cursor)[0]
-        self.cursor = cursor
 
     # ---#
     def fit(
@@ -227,93 +226,118 @@ p: int, optional
 	Parameters
 	----------
 	input_relation: str/vDataFrame
-		Train relation.
+		Training relation.
 	X: list, optional
 		List of the predictors. If empty, all the numerical vcolumns will be used.
 	key_columns: list, optional
 		Columns not used during the algorithm computation but which will be used
 		to create the final relation.
 	index: str, optional
-		Index to use to identify each row separately. It is highly recommanded to
-		have one already in the main table to avoid creation of temporary tables.
+		Index used to identify each row separately. It is highly recommanded to
+        have one already in the main table to avoid creating temporary tables.
 
 	Returns
 	-------
 	object
  		self
 		"""
+        if isinstance(key_columns, str):
+            key_columns = [key_columns]
+        if isinstance(X, str):
+            X = [X]
         check_types(
             [
-                ("input_relation", input_relation, [str, vDataFrame],),
-                ("X", X, [list],),
-                ("key_columns", key_columns, [list],),
-                ("index", index, [str],),
+                ("input_relation", input_relation, [str, vDataFrame]),
+                ("X", X, [list]),
+                ("key_columns", key_columns, [list]),
+                ("index", index, [str]),
             ]
         )
-        self.cursor = check_cursor(self.cursor, input_relation, True)[0]
-        check_model(name=self.name, cursor=self.cursor)
+        if verticapy.options["overwrite_model"]:
+            self.drop()
+        else:
+            does_model_exist(name=self.name, raise_error=True)
         if isinstance(input_relation, vDataFrame):
             if not (X):
                 X = input_relation.numcol()
             input_relation = input_relation.__genSQL__()
         else:
             if not (X):
-                X = vDataFrame(input_relation, self.cursor).numcol()
-        X = [str_column(column) for column in X]
+                X = vDataFrame(input_relation).numcol()
+        X = [quote_ident(column) for column in X]
         self.X = X
-        self.key_columns = [str_column(column) for column in key_columns]
+        self.key_columns = [quote_ident(column) for column in key_columns]
         self.input_relation = input_relation
         schema, relation = schema_relation(input_relation)
-        cursor = self.cursor
-
-        def drop_temp_elem(cursor):
-            try:
-                cursor.execute(
-                    "DROP TABLE IF EXISTS v_temp_schema.VERTICAPY_MAIN_{}".format(
-                        get_session(cursor)
-                    )
-                )
-                cursor.execute(
-                    "DROP TABLE IF EXISTS v_temp_schema.VERTICAPY_DBSCAN_CLUSTERS"
-                )
-            except:
-                pass
-
+        name_main, name_dbscan_clusters = (
+            gen_tmp_name(name="main"),
+            gen_tmp_name(name="clusters"),
+        )
         try:
             if not (index):
                 index = "id"
-                main_table = "VERTICAPY_MAIN_{}".format(get_session(self.cursor))
-                drop_temp_elem(cursor)
-                sql = "CREATE LOCAL TEMPORARY TABLE {} ON COMMIT PRESERVE ROWS AS SELECT ROW_NUMBER() OVER() AS id, {} FROM {} WHERE {}".format(
-                    main_table,
+                drop(f"v_temp_schema.{name_main}", method="table")
+                sql = """CREATE LOCAL TEMPORARY TABLE {0} 
+                         ON COMMIT PRESERVE ROWS AS 
+                         SELECT /*+LABEL('learn.cluster.DBSCAN.fit')*/
+                            ROW_NUMBER() OVER() AS id, 
+                            {1} 
+                         FROM {2} 
+                         WHERE {3}""".format(
+                    name_main,
                     ", ".join(X + key_columns),
                     self.input_relation,
-                    " AND ".join(["{} IS NOT NULL".format(item) for item in X]),
+                    " AND ".join([f"{item} IS NOT NULL" for item in X]),
                 )
-                executeSQL(cursor, sql, "Computing the DBSCAN Table - STEP 0.")
+                executeSQL(sql, title="Computing the DBSCAN Table [Step 0]")
             else:
-                cursor.execute(
-                    "SELECT {} FROM {} LIMIT 10".format(
+                executeSQL(
+                    "SELECT /*+LABEL('learn.cluster.DBSCAN.fit')*/ {0} FROM {1} LIMIT 10".format(
                         ", ".join(X + key_columns + [index]), self.input_relation
-                    )
+                    ),
+                    print_time_sql=False,
                 )
-                main_table = self.input_relation
+                name_main = self.input_relation
             sql = [
-                "POWER(ABS(x.{} - y.{}), {})".format(X[i], X[i], self.parameters["p"])
+                "POWER(ABS(x.{0} - y.{0}), {1})".format(X[i], self.parameters["p"])
                 for i in range(len(X))
             ]
-            distance = "POWER({}, 1 / {})".format(" + ".join(sql), self.parameters["p"])
-            sql = "SELECT x.{} AS node_id, y.{} AS nn_id, {} AS distance FROM {} AS x CROSS JOIN {} AS y".format(
-                index, index, distance, main_table, main_table
+            distance = "POWER({0}, 1 / {1})".format(
+                " + ".join(sql), self.parameters["p"]
             )
-            sql = "SELECT node_id, nn_id, SUM(CASE WHEN distance <= {} THEN 1 ELSE 0 END) OVER (PARTITION BY node_id) AS density, distance FROM ({}) distance_table".format(
+            sql = """SELECT 
+                        x.{0} AS node_id, 
+                        y.{0} AS nn_id, 
+                        {1} AS distance 
+                     FROM {2} AS x 
+                     CROSS JOIN {2} AS y""".format(
+                index, distance, name_main
+            )
+            sql = """SELECT 
+                        node_id, 
+                        nn_id, 
+                        SUM(CASE WHEN distance <= {0} THEN 1 ELSE 0 END) 
+                            OVER (PARTITION BY node_id) AS density, 
+                        distance 
+                     FROM ({1}) distance_table""".format(
                 self.parameters["eps"], sql
             )
-            sql = "SELECT node_id, nn_id FROM ({}) VERTICAPY_SUBTABLE WHERE density > {} AND distance < {} AND node_id != nn_id".format(
-                sql, self.parameters["min_samples"], self.parameters["eps"]
+            if isinstance(verticapy.options["random_state"], int):
+                order_by = "ORDER BY node_id, nn_id"
+            else:
+                order_by = ""
+            sql = """SELECT /*+LABEL('learn.cluster.DBSCAN.fit')*/
+                        node_id, 
+                        nn_id 
+                     FROM ({0}) VERTICAPY_SUBTABLE 
+                     WHERE density > {1} 
+                        AND distance < {2} 
+                        AND node_id != nn_id {3}""".format(
+                sql, self.parameters["min_samples"], self.parameters["eps"], order_by,
+            )
+            graph = executeSQL(
+                sql, title="Computing the DBSCAN Table [Step 1]", method="fetchall"
             )
-            executeSQL(cursor, sql, "Computing the DBSCAN Table - STEP 1.")
-            graph = cursor.fetchall()
             main_nodes = list(
                 dict.fromkeys([elem[0] for elem in graph] + [elem[1] for elem in graph])
             )
@@ -335,53 +359,71 @@ p: int, optional
                         clusters[node] = clusters[node_neighbor]
                 del graph[0]
             try:
-                f = open("VERTICAPY_DBSCAN_CLUSTERS_ID.csv", "w")
+                f = open("{}.csv".format(name_dbscan_clusters), "w")
                 for elem in clusters:
                     f.write("{}, {}\n".format(elem, clusters[elem]))
                 f.close()
-                try:
-                    cursor.execute(
-                        "DROP TABLE IF EXISTS v_temp_schema.VERTICAPY_DBSCAN_CLUSTERS"
-                    )
-                except:
-                    pass
-                cursor.execute(
-                    "CREATE LOCAL TEMPORARY TABLE VERTICAPY_DBSCAN_CLUSTERS(node_id int, cluster int) ON COMMIT PRESERVE ROWS"
+                drop("v_temp_schema.{}".format(name_dbscan_clusters), method="table")
+                executeSQL(
+                    (
+                        f"CREATE LOCAL TEMPORARY TABLE {name_dbscan_clusters}"
+                        "(node_id int, cluster int) ON COMMIT PRESERVE ROWS"
+                    ),
+                    print_time_sql=False,
                 )
-                if isinstance(cursor, vertica_python.vertica.cursor.Cursor):
-                    with open("./VERTICAPY_DBSCAN_CLUSTERS_ID.csv", "r") as fs:
-                        cursor.copy(
-                            "COPY v_temp_schema.VERTICAPY_DBSCAN_CLUSTERS(node_id, cluster) FROM STDIN DELIMITER ',' ESCAPE AS '\\';",
-                            fs,
-                        )
-                else:
-                    cursor.execute(
-                        "COPY v_temp_schema.VERTICAPY_DBSCAN_CLUSTERS(node_id, cluster) FROM LOCAL './VERTICAPY_DBSCAN_CLUSTERS_ID.csv' DELIMITER ',' ESCAPE AS '\\';"
+                if isinstance(current_cursor(), vertica_python.vertica.cursor.Cursor):
+                    executeSQL(
+                        (
+                            f"COPY v_temp_schema.{name_dbscan_clusters}(node_id, cluster)"
+                            " FROM STDIN DELIMITER ',' ESCAPE AS '\\';"
+                        ),
+                        method="copy",
+                        print_time_sql=False,
+                        path=f"./{name_dbscan_clusters}.csv",
                     )
-                try:
-                    cursor.execute("COMMIT")
-                except:
-                    pass
-                os.remove("VERTICAPY_DBSCAN_CLUSTERS_ID.csv")
+                else:
+                    executeSQL(
+                        """COPY v_temp_schema.{0}(node_id, cluster) 
+                           FROM LOCAL './{0}.csv' DELIMITER ',' ESCAPE AS '\\';""".format(
+                            name_dbscan_clusters
+                        ),
+                        print_time_sql=False,
+                    )
+                executeSQL("COMMIT;", print_time_sql=False)
+                os.remove(f"{name_dbscan_clusters}.csv")
             except:
-                os.remove("VERTICAPY_DBSCAN_CLUSTERS_ID.csv")
+                os.remove(f"{name_dbscan_clusters}.csv")
                 raise
             self.n_cluster_ = i
             executeSQL(
-                cursor,
-                "CREATE TABLE {} AS SELECT {}, COALESCE(cluster, -1) AS dbscan_cluster FROM v_temp_schema.{} AS x LEFT JOIN v_temp_schema.VERTICAPY_DBSCAN_CLUSTERS AS y ON x.{} = y.node_id".format(
-                    self.name, ", ".join(self.X + self.key_columns), main_table, index
+                """CREATE TABLE {0} AS 
+                   SELECT /*+LABEL('learn.cluster.DBSCAN.fit')*/
+                        {1}, 
+                        COALESCE(cluster, -1) AS dbscan_cluster 
+                   FROM v_temp_schema.{2} AS x 
+                   LEFT JOIN v_temp_schema.{3} AS y 
+                   ON x.{4} = y.node_id""".format(
+                    self.name,
+                    ", ".join(self.X + self.key_columns),
+                    name_main,
+                    name_dbscan_clusters,
+                    index,
                 ),
-                "Computing the DBSCAN Table - STEP 2.",
+                title="Computing the DBSCAN Table [Step 2]",
             )
-            cursor.execute(
-                "SELECT COUNT(*) FROM {} WHERE dbscan_cluster = -1".format(self.name)
+            self.n_noise_ = executeSQL(
+                "SELECT /*+LABEL('learn.cluster.DBSCAN.fit')*/ COUNT(*) FROM {0} WHERE dbscan_cluster = -1".format(
+                    self.name
+                ),
+                method="fetchfirstelem",
+                print_time_sql=False,
             )
-            self.n_noise_ = cursor.fetchone()[0]
         except:
-            drop_temp_elem(cursor)
+            drop(f"v_temp_schema.{name_main}", method="table")
+            drop(f"v_temp_schema.{name_dbscan_clusters}", method="table")
             raise
-        drop_temp_elem(cursor)
+        drop(f"v_temp_schema.{name_main}", method="table")
+        drop(f"v_temp_schema.{name_dbscan_clusters}", method="table")
         model_save = {
             "type": "DBSCAN",
             "input_relation": self.input_relation,
@@ -394,10 +436,7 @@ p: int, optional
             "n_noise": self.n_noise_,
         }
         insert_verticapy_schema(
-            model_name=self.name,
-            model_type="DBSCAN",
-            model_save=model_save,
-            cursor=self.cursor,
+            model_name=self.name, model_type="DBSCAN", model_save=model_save,
         )
         return self
 
@@ -412,26 +451,24 @@ p: int, optional
 	vDataFrame
  		the vDataFrame including the prediction.
 		"""
-        return vDataFrame(self.name, self.cursor)
+        return vDataFrame(self.name)
 
 
 # ---#
 class KMeans(Clustering):
     """
 ---------------------------------------------------------------------------
-Creates a KMeans object by using the Vertica Highly Distributed and Scalable 
-KMeans on the data. K-means clustering is a method of vector quantization, 
-originally from signal processing, that aims to partition n observations into 
-k clusters in which each observation belongs to the cluster with the nearest 
-mean (cluster centers or cluster centroid), serving as a prototype of the 
-cluster. This results in a partitioning of the data space into Voronoi cells. 
+Creates a KMeans object using the Vertica k-means algorithm on the data. 
+k-means clustering is a method of vector quantization, originally from signal 
+processing, that aims to partition n observations into k clusters in which 
+each observation belongs to the cluster with the nearest mean (cluster centers 
+or cluster centroid), serving as a prototype of the cluster. This results in 
+a partitioning of the data space into Voronoi cells.
 
 Parameters
 ----------
 name: str
-	Name of the the model. The model will be stored in the DB.
-cursor: DBcursor, optional
-	Vertica DB cursor.
+	Name of the the model. The model will be stored in the database.
 n_cluster: int, optional
 	Number of clusters
 init: str/list, optional
@@ -450,13 +487,25 @@ tol: float, optional
     def __init__(
         self,
         name: str,
-        cursor=None,
         n_cluster: int = 8,
         init: str = "kmeanspp",
         max_iter: int = 300,
         tol: float = 1e-4,
     ):
-        check_types([("name", name, [str],)])
+        # Saving information to the query profile table
+        save_to_query_profile(
+            name="KMeans",
+            path="learn.cluster",
+            json_dict={
+                "name": name,
+                "n_cluster": n_cluster,
+                "init": init,
+                "max_iter": max_iter,
+                "tol": tol,
+            },
+        )
+        # -#
+        check_types([("name", name, [str])])
         self.type, self.name = "KMeans", name
         self.set_params(
             {
@@ -466,20 +515,26 @@ tol: float, optional
                 "tol": tol,
             }
         )
-        cursor = check_cursor(cursor)[0]
-        self.cursor = cursor
-        version(cursor=cursor, condition=[8, 0, 0])
+        version(condition=[8, 0, 0])
 
     # ---#
-    def plot_voronoi(self, ax=None):
+    def plot_voronoi(
+        self, max_nb_points: int = 50, plot_crosses: bool = True, ax=None, **style_kwds
+    ):
         """
     ---------------------------------------------------------------------------
     Draws the Voronoi Graph of the model.
 
     Parameters
     ----------
+    max_nb_points: int, optional
+        Maximum number of points to display.
+    plot_crosses: bool, optional
+        If set to True, the centers are represented by white crosses.
     ax: Matplotlib axes object, optional
         The axes to plot on.
+    **style_kwds
+        Any optional parameter to pass to the Matplotlib functions.
 
     Returns
     -------
@@ -487,13 +542,20 @@ tol: float, optional
         Matplotlib Figure
         """
         if len(self.X) == 2:
-            from verticapy.learn.plot import voronoi_plot
+            from verticapy.learn.mlplot import voronoi_plot
 
-            query = "SELECT GET_MODEL_ATTRIBUTE(USING PARAMETERS model_name = '{}', attr_name = 'centers')".format(
+            query = "SELECT /*+LABEL('learn.cluster.KMeans.plot_voronoi')*/ GET_MODEL_ATTRIBUTE(USING PARAMETERS model_name = '{}', attr_name = 'centers')".format(
                 self.name
             )
-            self.cursor.execute(query)
-            clusters = self.cursor.fetchall()
-            return voronoi_plot(clusters=clusters, columns=self.X, ax=ax)
+            clusters = executeSQL(query, print_time_sql=False, method="fetchall")
+            return voronoi_plot(
+                clusters=clusters,
+                columns=self.X,
+                input_relation=self.input_relation,
+                plot_crosses=plot_crosses,
+                ax=ax,
+                max_nb_points=max_nb_points,
+                **style_kwds,
+            )
         else:
             raise Exception("Voronoi Plots are only available in 2D")
