@@ -386,7 +386,7 @@ class XGBoost_utils:
             len(self.classes_) == 2 and self.classes_[1] == 1 and self.classes_[0] == 0
         ):
             prior_ = executeSQL(
-                "SELECT AVG({}) FROM {} WHERE {}".format(
+                "SELECT /*+LABEL('learn.ensemble.XGBoost_utils.get_prior')*/ AVG({}) FROM {} WHERE {}".format(
                     self.y, self.input_relation, " AND ".join(condition)
                 ),
                 method="fetchfirstelem",
@@ -396,14 +396,14 @@ class XGBoost_utils:
             prior_ = []
             for elem in self.classes_:
                 avg = executeSQL(
-                    "SELECT COUNT(*) FROM {} WHERE {} AND {} = '{}'".format(
+                    "SELECT /*+LABEL('learn.ensemble.XGBoost_utils.get_prior')*/ COUNT(*) FROM {} WHERE {} AND {} = '{}'".format(
                         self.input_relation, " AND ".join(condition), self.y, elem
                     ),
                     method="fetchfirstelem",
                     print_time_sql=False,
                 )
                 avg /= executeSQL(
-                    "SELECT COUNT(*) FROM {} WHERE {}".format(
+                    "SELECT /*+LABEL('learn.ensemble.XGBoost_utils.get_prior')*/ COUNT(*) FROM {} WHERE {}".format(
                         self.input_relation, " AND ".join(condition)
                     ),
                     method="fetchfirstelem",
@@ -451,6 +451,20 @@ col_sample_by_tree: float, optional
         sample: float = 0.632,
         col_sample_by_tree: float = 1.0,
     ):
+        # Saving information to the query profile table
+        save_to_query_profile(
+            name="IsolationForest",
+            path="learn.ensemble",
+            json_dict={
+                "name": name,
+                "n_estimators": n_estimators,
+                "max_depth": max_depth,
+                "nbins": nbins,
+                "sample": sample,
+                "col_sample_by_tree": col_sample_by_tree,
+            },
+        )
+        # -#
         version(condition=[12, 0, 0])
         check_types([("name", name, [str], False)])
         self.type, self.name = "IsolationForest", name
@@ -463,6 +477,193 @@ col_sample_by_tree: float, optional
         }
         self.set_params(params)
 
+    # ---#
+    def decision_function(
+        self,
+        vdf: Union[str, vDataFrame],
+        X: list = [],
+        name: str = "",
+        inplace: bool = True,
+    ):
+        """
+    ---------------------------------------------------------------------------
+    Returns the anomaly score using the input relation.
+
+    Parameters
+    ----------
+    vdf: str/vDataFrame
+        Object to use for the prediction. You can specify a customized 
+        relation if it is enclosed with an alias. For example, 
+        "(SELECT 1) x" is correct, whereas "(SELECT 1)" and "SELECT 1" are 
+        incorrect.
+    X: list, optional
+        List of columns used to deploy the models. If empty, the model
+        predictors are used.
+    name: str, optional
+        Name of the additional vColumn. If empty, a name is generated.
+    inplace: bool, optional
+        If True, the prediction is added to the vDataFrame.
+
+    Returns
+    -------
+    vDataFrame
+        the input object.
+        """
+        # Inititalization
+        check_types(
+            [
+                ("name", name, [str]),
+                ("vdf", vdf, [str, vDataFrame]),
+                ("inplace", inplace, [bool]),
+            ],
+        )
+        if isinstance(vdf, str):
+            vdf = vDataFrameSQL(relation=vdf)
+        if not (name):
+            name = gen_name([self.type, self.name])
+
+        # In Place
+        vdf_return = vdf if inplace else vdf.copy()
+
+        # Result
+        return vdf_return.eval(name, self.deploySQL(X=X, return_score=True,))
+
+    # ---#
+    def deploySQL(
+        self,
+        X: list = [],
+        cutoff: float = 0.7,
+        contamination: float = None,
+        return_score: bool = False,
+    ):
+        """
+    ---------------------------------------------------------------------------
+    Returns the SQL code needed to deploy the model. 
+
+    Parameters
+    ----------
+    X: list, optional
+        List of the columns used to deploy the model. If empty, the model
+        predictors are used.
+    cutoff: float, optional
+        Float in the range (0.0, 1.0), specifies the threshold that 
+        determines if a data point is an anomaly. If the anomaly_score 
+        for a data point is greater than or equal to the cutoff, 
+        the data point is marked as an anomaly.
+    contamination: float, optional
+        Float in the range (0,1), the approximate ratio of data points in the 
+        training data that should be labeled as anomalous. If this parameter is 
+        specified, the cutoff parameter is ignored.
+    return_score: bool, optional
+        If set to True, the anomaly score is returned, and the parameters 'cutoff'
+        and 'contamination' are ignored.
+
+    Returns
+    -------
+    str
+        the SQL code needed to deploy the model.
+        """
+        if isinstance(X, str):
+            X = [X]
+        check_types(
+            [
+                ("X", X, [list]),
+                ("cutoff", cutoff, [float]),
+                ("contamination", contamination, [float]),
+                ("return_score", return_score, [bool]),
+            ]
+        )
+        if contamination and not (return_score):
+            assert 0 < contamination < 1, ParameterError(
+                "Incorrect parameter 'contamination'.\nThe parameter "
+                "'contamination' must be between 0.0 and 1.0, exclusive."
+            )
+        elif not (return_score):
+            assert 0 < cutoff < 1, ParameterError(
+                "Incorrect parameter 'cutoff'.\nThe parameter "
+                "'cutoff' must be between 0.0 and 1.0, exclusive."
+            )
+        X = [quote_ident(elem) for elem in X]
+        if return_score:
+            other_parameters = ""
+        elif contamination:
+            other_parameters = f", contamination = {contamination}"
+        else:
+            other_parameters = f", threshold = {cutoff}"
+        fun = self.get_model_fun()[1]
+        sql = "{}({} USING PARAMETERS model_name = '{}', match_by_pos = 'true'{})".format(
+            fun, ", ".join(self.X if not (X) else X), self.name, other_parameters,
+        )
+        if return_score:
+            sql = f"({sql}).anomaly_score"
+        else:
+            sql = f"(({sql}).is_anomaly)::int"
+        return sql
+
+    # ---#
+    def predict(
+        self,
+        vdf: Union[str, vDataFrame],
+        X: list = [],
+        name: str = "",
+        cutoff: float = 0.7,
+        contamination: float = None,
+        inplace: bool = True,
+    ):
+        """
+    ---------------------------------------------------------------------------
+    Predicts using the input relation.
+
+    Parameters
+    ----------
+    vdf: str/vDataFrame
+        Object to use for the prediction. You can specify a customized 
+        relation if it is enclosed with an alias. For example, 
+        "(SELECT 1) x" is correct, whereas "(SELECT 1)" and "SELECT 1" are 
+        incorrect.
+    X: list, optional
+        List of the columns used to deploy the model. If empty, the model
+        predictors are used.
+    name: str, optional
+        Name of the additional vColumn. If empty, a name is generated.
+    cutoff: float, optional
+        Float in the range (0.0, 1.0), specifies the threshold that 
+        determines if a data point is an anomaly. If the anomaly_score 
+        for a data point is greater than or equal to the cutfoff, 
+        the data point is marked as an anomaly.
+    contamination: float, optional
+        Float in the range (0,1), the approximate ratio of data points in the
+        training data that should be labeled as anomalous. If this parameter is 
+        specified, the cutoff parameter is ignored.
+    inplace: bool, optional
+        If set to True, the prediction is added to the vDataFrame.
+
+    Returns
+    -------
+    vDataFrame
+        the input object.
+        """
+        # Inititalization
+        check_types(
+            [
+                ("name", name, [str]),
+                ("vdf", vdf, [str, vDataFrame]),
+                ("inplace", inplace, [bool]),
+            ],
+        )
+        if isinstance(vdf, str):
+            vdf = vDataFrameSQL(relation=vdf)
+        if not (name):
+            name = gen_name([self.type, self.name])
+
+        # In Place
+        vdf_return = vdf if inplace else vdf.copy()
+
+        # Result
+        return vdf_return.eval(
+            name, self.deploySQL(cutoff=cutoff, contamination=contamination, X=X)
+        )
+
 
 # ---#
 class RandomForestClassifier(MulticlassClassifier, Tree):
@@ -517,6 +718,23 @@ nbins: int, optional
         min_info_gain: float = 0.0,
         nbins: int = 32,
     ):
+        # Saving information to the query profile table
+        save_to_query_profile(
+            name="RandomForestClassifier",
+            path="learn.ensemble",
+            json_dict={
+                "name": name,
+                "n_estimators": n_estimators,
+                "max_features": max_features,
+                "max_leaf_nodes": max_leaf_nodes,
+                "sample": sample,
+                "max_depth": max_depth,
+                "min_samples_leaf": min_samples_leaf,
+                "min_info_gain": min_info_gain,
+                "nbins": nbins,
+            },
+        )
+        # -#
         version(condition=[8, 1, 1])
         check_types([("name", name, [str], False)])
         self.type, self.name = "RandomForestClassifier", name
@@ -587,6 +805,23 @@ nbins: int, optional
         min_info_gain: float = 0.0,
         nbins: int = 32,
     ):
+        # Saving information to the query profile table
+        save_to_query_profile(
+            name="RandomForestRegressor",
+            path="learn.ensemble",
+            json_dict={
+                "name": name,
+                "n_estimators": n_estimators,
+                "max_features": max_features,
+                "max_leaf_nodes": max_leaf_nodes,
+                "sample": sample,
+                "max_depth": max_depth,
+                "min_samples_leaf": min_samples_leaf,
+                "min_info_gain": min_info_gain,
+                "nbins": nbins,
+            },
+        )
+        # -#
         version(condition=[9, 0, 1])
         check_types([("name", name, [str], False)])
         self.type, self.name = "RandomForestRegressor", name
@@ -667,6 +902,26 @@ col_sample_by_node: float, optional
         col_sample_by_tree: float = 1.0,
         col_sample_by_node: float = 1.0,
     ):
+        # Saving information to the query profile table
+        save_to_query_profile(
+            name="XGBoostClassifier",
+            path="learn.ensemble",
+            json_dict={
+                "name": name,
+                "max_ntree": max_ntree,
+                "max_depth": max_depth,
+                "nbins": nbins,
+                "split_proposal_method": split_proposal_method,
+                "tol": tol,
+                "learning_rate": learning_rate,
+                "min_split_loss": min_split_loss,
+                "weight_reg": weight_reg,
+                "sample": sample,
+                "col_sample_by_tree": col_sample_by_tree,
+                "col_sample_by_node": col_sample_by_node,
+            },
+        )
+        # -#
         version(condition=[10, 1, 0])
         check_types([("name", name, [str], False)])
         self.type, self.name = "XGBoostClassifier", name
@@ -752,6 +1007,26 @@ col_sample_by_node: float, optional
         col_sample_by_tree: float = 1.0,
         col_sample_by_node: float = 1.0,
     ):
+        # Saving information to the query profile table
+        save_to_query_profile(
+            name="XGBoostRegressor",
+            path="learn.ensemble",
+            json_dict={
+                "name": name,
+                "max_ntree": max_ntree,
+                "max_depth": max_depth,
+                "nbins": nbins,
+                "split_proposal_method": split_proposal_method,
+                "tol": tol,
+                "learning_rate": learning_rate,
+                "min_split_loss": min_split_loss,
+                "weight_reg": weight_reg,
+                "sample": sample,
+                "col_sample_by_tree": col_sample_by_tree,
+                "col_sample_by_node": col_sample_by_node,
+            },
+        )
+        # -#
         version(condition=[10, 1, 0])
         check_types([("name", name, [str], False)])
         self.type, self.name = "XGBoostRegressor", name
