@@ -88,6 +88,13 @@ Returns
 bool
     True if the schema was successfully created, False otherwise.
     """
+    # Saving information to the query profile table
+    save_to_query_profile(
+        name="create_schema",
+        path="utilities",
+        json_dict={"schema": schema, "raise_error": raise_error,},
+    )
+    # -#
     try:
         executeSQL(f"CREATE SCHEMA {schema};", title="Creating the new schema.")
         return True
@@ -137,6 +144,21 @@ Returns
 bool
     True if the table was successfully created, False otherwise.
     """
+    # Saving information to the query profile table
+    save_to_query_profile(
+        name="create_table",
+        path="utilities",
+        json_dict={
+            "table_name": table_name,
+            "schema": schema,
+            "dtype": dtype,
+            "genSQL": genSQL,
+            "temporary_table": temporary_table,
+            "temporary_local_table": temporary_local_table,
+            "raise_error": raise_error,
+        },
+    )
+    # -#
     check_types(
         [
             ("table_name", table_name, [str]),
@@ -184,6 +206,11 @@ def create_verticapy_schema():
 ---------------------------------------------------------------------------
 Creates a schema named 'verticapy' used to store VerticaPy extended models.
     """
+    # Saving information to the query profile table
+    save_to_query_profile(
+        name="create_verticapy_schema", path="utilities", json_dict={},
+    )
+    # -#
     sql = "CREATE SCHEMA IF NOT EXISTS verticapy;"
     executeSQL(sql, title="Creating VerticaPy schema.")
     sql = """CREATE TABLE IF NOT EXISTS verticapy.models (model_name VARCHAR(128), 
@@ -229,6 +256,13 @@ Returns
 bool
     True if the relation was dropped, False otherwise.
     """
+    # Saving information to the query profile table
+    save_to_query_profile(
+        name="drop",
+        path="utilities",
+        json_dict={"name": name, "method": method, "raise_error": raise_error,},
+    )
+    # -#
     if "relation_type" in kwds and method == "auto":
         method = kwds["relation_type"]
     if isinstance(method, str):
@@ -251,13 +285,13 @@ bool
     if method == "auto":
         fail, end_conditions = False, False
         query = (
-            f"SELECT * FROM columns WHERE table_schema = '{schema}'"
+            f"SELECT /*+LABEL('utilities.drop')*/ * FROM columns WHERE table_schema = '{schema}'"
             f" AND table_name = '{relation}'"
         )
         result = executeSQL(query, print_time_sql=False, method="fetchrow")
         if not (result):
             query = (
-                f"SELECT * FROM view_columns WHERE table_schema = '{schema}'"
+                f"SELECT /*+LABEL('utilities.drop')*/ * FROM view_columns WHERE table_schema = '{schema}'"
                 f" AND table_name = '{relation}'"
             )
             result = executeSQL(query, print_time_sql=False, method="fetchrow")
@@ -267,7 +301,7 @@ bool
         if not (result):
             try:
                 query = (
-                    "SELECT model_type FROM verticapy.models WHERE "
+                    "SELECT /*+LABEL('utilities.drop')*/ model_type FROM verticapy.models WHERE "
                     "LOWER(model_name) = '{0}'"
                 ).format(quote_ident(name).lower())
                 result = executeSQL(query, print_time_sql=False, method="fetchrow")
@@ -277,14 +311,14 @@ bool
             method = "view"
             end_conditions = True
         if not (result):
-            query = f"SELECT * FROM models WHERE schema_name = '{schema}' AND model_name = '{relation}'"
+            query = f"SELECT /*+LABEL('utilities.drop')*/ * FROM models WHERE schema_name = '{schema}' AND model_name = '{relation}'"
             result = executeSQL(query, print_time_sql=False, method="fetchrow")
         elif not (end_conditions):
             method = "model"
             end_conditions = True
         if not (result):
             query = (
-                "SELECT * FROM (SELECT STV_Describe_Index () OVER ()) x  WHERE name IN "
+                "SELECT /*+LABEL('utilities.drop')*/ * FROM (SELECT STV_Describe_Index () OVER ()) x  WHERE name IN "
                 f"('{schema}.{relation}', '{relation}', '\"{schema}\".\"{relation}\"', "
                 f"'\"{relation}\"', '{schema}.\"{relation}\"', '\"{schema}\".{relation}')"
             )
@@ -294,7 +328,7 @@ bool
             end_conditions = True
         if not (result):
             try:
-                query = f'SELECT * FROM "{schema}"."{relation}" LIMIT 0;'
+                query = f'SELECT /*+LABEL(\'utilities.drop\')*/ * FROM "{schema}"."{relation}" LIMIT 0;'
                 executeSQL(query, print_time_sql=False)
                 method = "text"
             except:
@@ -312,7 +346,7 @@ bool
     if method == "model":
         model_type = kwds["model_type"] if "model_type" in kwds else None
         try:
-            query = "SELECT model_type FROM verticapy.models WHERE LOWER(model_name) = '{}'".format(
+            query = "SELECT /*+LABEL('utilities.drop')*/ model_type FROM verticapy.models WHERE LOWER(model_name) = '{}'".format(
                 quote_ident(name).lower()
             )
             result = executeSQL(query, print_time_sql=False, method="fetchfirstelem")
@@ -340,7 +374,7 @@ bool
             elif model_type == "CountVectorizer":
                 drop(name, method="text")
                 query = (
-                    "SELECT value FROM verticapy.attr WHERE LOWER(model_name) = '{0}' "
+                    "SELECT /*+LABEL('utilities.drop')*/ value FROM verticapy.attr WHERE LOWER(model_name) = '{0}' "
                     "AND attr_name = 'countvectorizer_table'"
                 ).format(quote_ident(name).lower())
                 res = executeSQL(query, print_time_sql=False, method="fetchrow")
@@ -355,12 +389,12 @@ bool
             elif model_type == "AutoDataPrep":
                 drop(name, method="table")
             if is_in_verticapy_schema:
-                sql = "DELETE FROM verticapy.models WHERE LOWER(model_name) = '{}';".format(
+                sql = "DELETE /*+LABEL('utilities.drop')*/ FROM verticapy.models WHERE LOWER(model_name) = '{}';".format(
                     quote_ident(name).lower()
                 )
                 executeSQL(sql, title="Deleting vModel.")
                 executeSQL("COMMIT;", title="Commit.")
-                sql = "DELETE FROM verticapy.attr WHERE LOWER(model_name) = '{}';".format(
+                sql = "DELETE /*+LABEL('utilities.drop')*/ FROM verticapy.attr WHERE LOWER(model_name) = '{}';".format(
                     quote_ident(name).lower()
                 )
                 executeSQL(sql, title="Deleting vModel attributes.")
@@ -386,7 +420,7 @@ bool
                 raise
             result = False
     elif method == "temp":
-        sql = """SELECT 
+        sql = """SELECT /*+LABEL('utilities.drop')*/
                     table_schema, table_name 
                  FROM columns 
                  WHERE LOWER(table_name) LIKE '%_verticapy_tmp_%' 
@@ -397,7 +431,7 @@ bool
                 elem[0].replace('"', '""'), elem[1].replace('"', '""')
             )
             drop(table, method="table")
-        sql = """SELECT 
+        sql = """SELECT /*+LABEL('utilities.drop')*/
                     table_schema, table_name 
                  FROM view_columns 
                  WHERE LOWER(table_name) LIKE '%_verticapy_tmp_%' 
@@ -434,6 +468,13 @@ def readSQL(query: str, time_on: bool = False, limit: int = 100):
  	tablesample
  		Result of the query.
 	"""
+    # Saving information to the query profile table
+    save_to_query_profile(
+        name="readSQL",
+        path="utilities",
+        json_dict={"query": query, "time_on": time_on, "limit": limit,},
+    )
+    # -#
     check_types(
         [
             ("query", query, [str]),
@@ -444,7 +485,9 @@ def readSQL(query: str, time_on: bool = False, limit: int = 100):
     while len(query) > 0 and query[-1] in (";", " "):
         query = query[:-1]
     count = executeSQL(
-        "SELECT COUNT(*) FROM ({}) VERTICAPY_SUBTABLE".format(query),
+        "SELECT /*+LABEL('utilities.readSQL')*/ COUNT(*) FROM ({}) VERTICAPY_SUBTABLE".format(
+            query
+        ),
         method="fetchfirstelem",
         print_time_sql=False,
     )
@@ -493,6 +536,13 @@ Returns
 list of tuples
 	The list of the different columns and their respective type.
 	"""
+    # Saving information to the query profile table
+    save_to_query_profile(
+        name="get_data_types",
+        path="utilities",
+        json_dict={"expr": expr, "column_name": column_name,},
+    )
+    # -#
     from verticapy.connect import current_cursor
 
     if isinstance(current_cursor(), vertica_python.vertica.cursor.Cursor):
@@ -545,7 +595,7 @@ list of tuples
         drop("{}.{}".format(schema, tmp_name), method="table")
         raise
     query = (
-        "SELECT column_name, data_type FROM columns WHERE {0}table_name = '{1}'"
+        "SELECT /*+LABEL('utilities.get_data_types')*/ column_name, data_type FROM columns WHERE {0}table_name = '{1}'"
         " AND table_schema = '{2}' ORDER BY ordinal_position"
     ).format(
         f"column_name = '{column_name}' AND " if (column_name) else "",
@@ -607,6 +657,19 @@ See Also
 --------
 pandas_to_vertica : Ingests a pandas DataFrame into the Vertica database.
     """
+    # Saving information to the query profile table
+    save_to_query_profile(
+        name="insert_into",
+        path="utilities",
+        json_dict={
+            "table_name": table_name,
+            "schema": schema,
+            "column_names": column_names,
+            "copy": copy,
+            "genSQL": genSQL,
+        },
+    )
+    # -#
     check_types(
         [
             ("table_name", table_name, [str]),
@@ -621,7 +684,7 @@ pandas_to_vertica : Ingests a pandas DataFrame into the Vertica database.
         schema = verticapy.options["temp_schema"]
     input_relation = "{}.{}".format(quote_ident(schema), quote_ident(table_name))
     if not (column_names):
-        query = f"""SELECT 
+        query = f"""SELECT /*+LABEL('utilities.insert_into')*/
                         column_name
                     FROM columns 
                     WHERE table_name = '{table_name}' 
@@ -748,6 +811,20 @@ See Also
 read_csv  : Ingests a  CSV file into the Vertica database.
 read_json : Ingests a JSON file into the Vertica database.
     """
+    # Saving information to the query profile table
+    save_to_query_profile(
+        name="pandas_to_vertica",
+        path="utilities",
+        json_dict={
+            "name": name,
+            "schema": schema,
+            "parse_nrows": parse_nrows,
+            "dtype": dtype,
+            "temp_path": temp_path,
+            "insert": insert,
+        },
+    )
+    # -#
     check_types(
         [
             ("name", name, [str]),
@@ -792,6 +869,15 @@ read_json : Ingests a JSON file into the Vertica database.
         tmp_df.to_csv(
             path, index=False, quoting=csv.QUOTE_NONE, quotechar="", escapechar="\027"
         )
+        if str_cols:
+            # to_csv is adding an undesired special character
+            # we remove it
+            with open(path, "r") as f:
+                filedata = f.read()
+            filedata = filedata.replace(",", ",")
+            with open(path, "w") as f:
+                f.write(filedata)
+
         if insert:
             input_relation = "{}.{}".format(quote_ident(schema), quote_ident(name))
             query = """COPY {0}({1}) 
@@ -887,6 +973,22 @@ See Also
 read_csv  : Ingests a CSV file into the Vertica database.
 read_json : Ingests a JSON file into the Vertica database.
 	"""
+    # Saving information to the query profile table
+    save_to_query_profile(
+        name="pcsv",
+        path="utilities",
+        json_dict={
+            "path": path,
+            "sep": sep,
+            "header": header,
+            "header_names": header_names,
+            "na_rep": na_rep,
+            "quotechar": quotechar,
+            "escape": escape,
+            "ingest_local": ingest_local,
+        },
+    )
+    # -#
     flex_name = gen_tmp_name(name="flex")[1:-1]
     executeSQL(
         """CREATE FLEX LOCAL TEMP TABLE {0}(x int) 
@@ -923,18 +1025,18 @@ read_json : Ingests a JSON file into the Vertica database.
         title="Parsing the data.",
     )
     executeSQL(
-        f"SELECT compute_flextable_keys('{flex_name}');",
+        f"SELECT /*+LABEL('utilities.pcsv')*/ compute_flextable_keys('{flex_name}');",
         title="Guessing flex tables keys.",
     )
     result = executeSQL(
-        f"SELECT key_name, data_type_guess FROM {flex_name}_keys",
+        f"SELECT /*+LABEL('utilities.pcsv')*/ key_name, data_type_guess FROM {flex_name}_keys",
         title="Guessing the data types.",
         method="fetchall",
     )
     dtype = {}
     for column_dtype in result:
         try:
-            query = """SELECT 
+            query = """SELECT /*+LABEL('utilities.pcsv')*/
                         (CASE 
                             WHEN "{0}"=\'{1}\' THEN NULL 
                             ELSE "{0}" 
@@ -958,6 +1060,11 @@ def help_start():
 ---------------------------------------------------------------------------
 VERTICAPY Interactive Help (FAQ).
     """
+    # Saving information to the query profile table
+    save_to_query_profile(
+        name="help_start", path="utilities", json_dict={},
+    )
+    # -#
     try:
         from IPython.core.display import HTML, display, Markdown
     except:
@@ -1050,6 +1157,13 @@ See Also
 read_csv  : Ingests a CSV file into the Vertica database.
 read_json : Ingests a JSON file into the Vertica database.
 	"""
+    # Saving information to the query profile table
+    save_to_query_profile(
+        name="pjson",
+        path="utilities",
+        json_dict={"path": path, "ingest_local": ingest_local,},
+    )
+    # -#
     flex_name = gen_tmp_name(name="flex")[1:-1]
     executeSQL(
         "CREATE FLEX LOCAL TEMP TABLE {}(x int) ON COMMIT PRESERVE ROWS;".format(
@@ -1064,11 +1178,15 @@ read_json : Ingests a JSON file into the Vertica database.
         title="Ingesting the data.",
     )
     executeSQL(
-        "SELECT compute_flextable_keys('{}');".format(flex_name),
+        "SELECT /*+LABEL('utilities.pjson')*/ compute_flextable_keys('{}');".format(
+            flex_name
+        ),
         title="Computing flex table keys.",
     )
     result = executeSQL(
-        "SELECT key_name, data_type_guess FROM {}_keys".format(flex_name),
+        "SELECT /*+LABEL('utilities.pjson')*/ key_name, data_type_guess FROM {}_keys".format(
+            flex_name
+        ),
         title="Guessing data types.",
         method="fetchall",
     )
@@ -1164,6 +1282,30 @@ See Also
 --------
 read_json : Ingests a JSON file into the Vertica database.
 	"""
+    # Saving information to the query profile table
+    save_to_query_profile(
+        name="read_csv",
+        path="utilities",
+        json_dict={
+            "path": path,
+            "schema": schema,
+            "table_name": table_name,
+            "sep": sep,
+            "header": header,
+            "header_names": header_names,
+            "na_rep": na_rep,
+            "quotechar": quotechar,
+            "escape": escape,
+            "genSQL": genSQL,
+            "parse_nrows": parse_nrows,
+            "insert": insert,
+            "temporary_table": temporary_table,
+            "temporary_local_table": temporary_local_table,
+            "gen_tmp_table_name": gen_tmp_table_name,
+            "ingest_local": ingest_local,
+        },
+    )
+    # -#
     check_types(
         [
             ("path", path, [str]),
@@ -1223,7 +1365,7 @@ read_json : Ingests a JSON file into the Vertica database.
             "the table when ingesting multiple files."
         )
         table_name = path.split("/")[-2]
-    query = """SELECT 
+    query = """SELECT /*+LABEL('utilities.read_csv')*/
                     column_name 
                FROM columns 
                WHERE table_name = '{0}' 
@@ -1353,7 +1495,9 @@ read_json : Ingests a JSON file into the Vertica database.
             if query1:
                 executeSQL(query1, "Creating the table.")
             executeSQL(
-                query2.format("{}'{}'".format("LOCAL " if ingest_local else "", path)),
+                query2.format(
+                    "{0}'{1}'".format("LOCAL " if ingest_local else "", path)
+                ),
                 "Ingesting the data.",
             )
             if (
@@ -1429,8 +1573,27 @@ See Also
 --------
 read_csv : Ingests a CSV file into the Vertica database.
 	"""
+    # Saving information to the query profile table
+    save_to_query_profile(
+        name="read_json",
+        path="utilities",
+        json_dict={
+            "path": path,
+            "schema": schema,
+            "table_name": table_name,
+            "usecols": usecols,
+            "new_name": new_name,
+            "insert": insert,
+            "temporary_table": temporary_table,
+            "temporary_local_table": temporary_local_table,
+            "gen_tmp_table_name": gen_tmp_table_name,
+            "ingest_local": ingest_local,
+        },
+    )
+    # -#
     check_types(
         [
+            ("path", path, [str]),
             ("schema", schema, [str]),
             ("table_name", table_name, [str]),
             ("usecols", usecols, [list]),
@@ -1460,7 +1623,7 @@ read_csv : Ingests a CSV file into the Vertica database.
     if not (table_name):
         table_name = path.split("/")[-1].split(".json")[0]
     query = (
-        "SELECT column_name, data_type FROM columns WHERE table_name = '{0}' "
+        "SELECT /*+LABEL('utilities.read_json')*/ column_name, data_type FROM columns WHERE table_name = '{0}' "
         "AND table_schema = '{1}' ORDER BY ordinal_position"
     ).format(table_name.replace("'", "''"), schema.replace("'", "''"))
     column_name = executeSQL(
@@ -1493,11 +1656,15 @@ read_csv : Ingests a CSV file into the Vertica database.
             title="Ingesting the data in the flex table.",
         )
         executeSQL(
-            "SELECT compute_flextable_keys('{}');".format(flex_name),
+            "SELECT /*+LABEL('utilities.read_json')*/ compute_flextable_keys('{}');".format(
+                flex_name
+            ),
             title="Computing flex table keys.",
         )
         result = executeSQL(
-            "SELECT key_name, data_type_guess FROM {}_keys".format(flex_name),
+            "SELECT /*+LABEL('utilities.read_json')*/ key_name, data_type_guess FROM {}_keys".format(
+                flex_name
+            ),
             title="Guessing data types.",
             method="fetchall",
         )
@@ -1505,7 +1672,7 @@ read_csv : Ingests a CSV file into the Vertica database.
         for column_dtype in result:
             try:
                 executeSQL(
-                    'SELECT "{}"::{} FROM {} LIMIT 1000'.format(
+                    "SELECT /*+LABEL('utilities.read_json')*/ \"{}\"::{} FROM {} LIMIT 1000".format(
                         column_dtype[0], column_dtype[1], flex_name
                     ),
                     print_time_sql=False,
@@ -1530,7 +1697,7 @@ read_csv : Ingests a CSV file into the Vertica database.
             temp = "TEMPORARY " if temporary_table else ""
             temp = "LOCAL TEMPORARY " if temporary_local_table else ""
             executeSQL(
-                "CREATE {}TABLE {}{} AS SELECT {} FROM {}".format(
+                "CREATE {}TABLE {}{} AS SELECT /*+LABEL('utilities.read_json')*/ {} FROM {}".format(
                     temp,
                     input_relation,
                     " ON COMMIT PRESERVE ROWS" if temp else "",
@@ -1569,7 +1736,7 @@ read_csv : Ingests a CSV file into the Vertica database.
                     ]
                 )
             executeSQL(
-                "INSERT INTO {} SELECT {} FROM {}".format(
+                "INSERT /*+LABEL('utilities.read_json')*/ INTO {} SELECT {} FROM {}".format(
                     input_relation, ", ".join(final_transformation), flex_name
                 ),
                 title="Inserting data into table.",
@@ -1603,6 +1770,13 @@ Returns
 vDataFrame
     The vDataFrame of the relation.
     """
+    # Saving information to the query profile table
+    save_to_query_profile(
+        name="read_shp",
+        path="utilities",
+        json_dict={"path": path, "schema": schema, "table_name": table_name,},
+    )
+    # -#
     check_types(
         [
             ("path", path, [str]),
@@ -1615,7 +1789,7 @@ vDataFrame
     if file_extension != "shp":
         raise ExtensionError("The file extension is incorrect !")
     query = (
-        f"SELECT STV_ShpCreateTable(USING PARAMETERS file='{path}')"
+        f"SELECT /*+LABEL('utilities.read_shp')*/ STV_ShpCreateTable(USING PARAMETERS file='{path}')"
         " OVER() AS create_shp_table;"
     )
     result = executeSQL(query, title="Getting SHP definition.", method="fetchall")
@@ -1636,6 +1810,114 @@ vDataFrame
     return vDataFrame(table_name, schema=schema)
 
 
+# ---#
+def save_to_query_profile(
+    name: str,
+    path: str = "",
+    json_dict: dict = {},
+    query_label: str = "verticapy_json",
+    return_query: bool = False,
+    add_identifier: bool = True,
+):
+    """
+---------------------------------------------------------------------------
+Saves information about the specified VerticaPy method to the QUERY_PROFILES 
+table in the Vertica database. It is used to collect usage statistics on 
+methods and their parameters. This function generates a JSON string.
+
+Parameters
+----------
+name: str
+    Name of the method.
+path: str, optional
+    Path to the function or method.
+json_dict: dict, optional
+    Dictionary of the different parameters to store.
+query_label: str, optional
+    Name to give to the identifier in the query profile table. If 
+    unspecified, the name of the method is used.
+return_query: bool, optional
+    If set to True, the query is returned.
+add_identifier: bool, optional
+    If set to True, the VerticaPy identifier is added to the generated json.
+
+Returns
+-------
+bool
+    True if the operation succeeded, False otherwise.
+    """
+    try:
+        check_types(
+            [
+                ("name", name, [str]),
+                ("path", path, [str]),
+                ("json_dict", json_dict, [dict]),
+                ("query_label", query_label, [str]),
+                ("return_query", return_query, [bool]),
+                ("add_identifier", add_identifier, [bool]),
+            ]
+        )
+
+        def dict_to_json_string(
+            name: str = "",
+            path: str = "",
+            json_dict: dict = {},
+            add_identifier: bool = False,
+        ):
+            from verticapy import vDataFrame
+            from verticapy.learn.vmodel import vModel
+
+            json = "{"
+            if name:
+                json += f'"verticapy_fname": "{name}", '
+            if path:
+                json += f'"verticapy_fpath": "{path}", '
+            if add_identifier:
+                json += '"verticapy_id": "{0}", '.format(
+                    verticapy.options["identifier"]
+                )
+            for elem in json_dict:
+                json += '"{0}": '.format(str(elem))
+                if isinstance(json_dict[elem], bool):
+                    json += "true" if json_dict[elem] else "false"
+                elif isinstance(json_dict[elem], (float, int)):
+                    json += "{0}".format(json_dict[elem])
+                elif json_dict[elem] is None:
+                    json += "null"
+                elif isinstance(json_dict[elem], vDataFrame):
+                    json += '"{0}"'.format(
+                        json_dict[elem].__genSQL__().replace('"', '\\"')
+                    )
+                elif isinstance(json_dict[elem], vModel):
+                    json += '"{0}"'.format(json_dict[elem].type)
+                elif isinstance(json_dict[elem], dict):
+                    json += dict_to_json_string(json_dict=json_dict[elem])
+                elif isinstance(json_dict[elem], list):
+                    json += '"{0}"'.format(
+                        ";".join([str(item) for item in json_dict[elem]])
+                    )
+                else:
+                    json += '"{0}"'.format(str(json_dict[elem]).replace('"', '\\"'))
+                json += ", "
+            json = json[:-2] + "}"
+            return json
+
+        query = "SELECT /*+LABEL('{0}')*/ '{1}'".format(
+            query_label.replace("'", "''"),
+            dict_to_json_string(name, path, json_dict, add_identifier).replace(
+                "'", "''"
+            ),
+        )
+        if return_query:
+            return query
+        executeSQL(
+            query, title="Sending query to save the information in query profile table."
+        )
+        return True
+    except:
+        return False
+
+
 # ---#
 def set_option(option: str, value: Union[bool, int, str] = None):
     """
@@ -1663,8 +1945,7 @@ def set_option(option: str, value: Union[bool, int, str] = None):
             If set to True, vDataFrames and tablesamples show a footer that includes information 
             about the displayed rows and columns.
         interactive    : bool
-            If set to True, verticaPy outputs will be displayed 
-            on interactive tables. 
+            If set to True, verticaPy outputs will be displayed on interactive tables. 
         max_columns    : int
             Maximum number of columns to display. If the parameter is incorrect, 
             nothing is changed.
@@ -1698,6 +1979,13 @@ def set_option(option: str, value: Union[bool, int, str] = None):
     value: object, optional
         New value of option.
     """
+    # Saving information to the query profile table
+    save_to_query_profile(
+        name="set_option",
+        path="utilities",
+        json_dict={"option": option, "value": value,},
+    )
+    # -#
     if isinstance(option, str):
         option = option.lower()
     check_types(
@@ -1761,6 +2049,7 @@ def set_option(option: str, value: Union[bool, int, str] = None):
         )
         if isinstance(value, str):
             verticapy.options["color_style"] = value
+            verticapy.options["colors"] = []
     elif option == "max_columns":
         check_types([("value", value, [int, float])])
         if value > 0:
@@ -1799,7 +2088,7 @@ def set_option(option: str, value: Union[bool, int, str] = None):
     elif option == "temp_schema":
         check_types([("value", value, [str])])
         if isinstance(value, str):
-            query = """SELECT 
+            query = """SELECT /*+LABEL('utilities.set_option')*/
                           schema_name 
                        FROM v_catalog.schemata 
                        WHERE schema_name = '{}' LIMIT 1;""".format(
@@ -2351,6 +2640,13 @@ def to_tablesample(
 	--------
 	tablesample : Object in memory created for rendering purposes.
 	"""
+    # Saving information to the query profile table
+    save_to_query_profile(
+        name="to_tablesample",
+        path="utilities",
+        json_dict={"query": query, "title": title, "max_columns": max_columns,},
+    )
+    # -#
     check_types(
         [("query", query, [str]), ("max_columns", max_columns, [int]),]
     )
@@ -2489,12 +2785,19 @@ list
     List containing the version information.
     [MAJOR, MINOR, PATCH, POST]
     """
+    # Saving information to the query profile table
+    save_to_query_profile(
+        name="version", path="utilities", json_dict={"condition": condition,},
+    )
+    # -#
     check_types([("condition", condition, [list])])
     if condition:
         condition = condition + [0 for elem in range(4 - len(condition))]
     if not (verticapy.options["vertica_version"]):
         version = executeSQL(
-            "SELECT version();", title="Getting the version.", method="fetchfirstelem"
+            "SELECT /*+LABEL('utilities.version')*/ version();",
+            title="Getting the version.",
+            method="fetchfirstelem",
         ).split("Vertica Analytic Database v")[1]
         version = version.split(".")
         result = []
